#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 crypton-connection
version:              0.4.5
visibility:           public
id:                   crypton-connection-0.4.5-L1gw2KXsHVeLjTVyybKyAs
key:                  crypton-connection-0.4.5-L1gw2KXsHVeLjTVyybKyAs
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             https://github.com/kazu-yamamoto/crypton-connection
synopsis:             Simple and easy network connection API
description:
    Simple network library for all your connection needs.

    Features: Really simple to use, SSL/TLS, SOCKS.

    This library provides a very simple api to create sockets
    to a destination with the choice of SSL/TLS, and SOCKS.

category:             Network
abi:                  f46a5b4b1f44c45f8276ea3c26f0a200
exposed:              True
exposed-modules:      Network.Connection Network.Connection.Internal
hidden-modules:       Network.Connection.Types
import-dirs:          /usr/lib/ghc-9.6.6/site-local/crypton-connection-0.4.5
library-dirs:         /usr/lib/ghc-9.6.6/site-local/crypton-connection-0.4.5
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/crypton-connection-0.4.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-crypton-connection
hs-libraries:         HScrypton-connection-0.4.5-L1gw2KXsHVeLjTVyybKyAs
depends:
    base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7
    crypton-socks-0.6.2-53iWPk5vNnQ5eophFGQFpQ
    crypton-x509-store-1.6.12-Co0ctBz0mYaCriLLJjRizT
    crypton-x509-system-1.6.7-AWccIegHxMGERGY32rSUFy
    data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz
    network-3.1.4.0-10rvNinchMB4AwxOArhT4I
    tls-2.0.6-K7g7Oy3E5e3DsNiPnXBpiH

haddock-interfaces:
    /usr/share/doc/haskell-crypton-connection/html/crypton-connection.haddock

haddock-html:         /usr/share/doc/haskell-crypton-connection/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

